/*
 *
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 * 
 * This file is part of de.bsvrz.ars.ars.
 * 
 * de.bsvrz.ars.ars is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * de.bsvrz.ars.ars is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.ars.ars.  If not, see <http://www.gnu.org/licenses/>.

 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436 
 * mail: <info@kappich.de>
 */

package de.bsvrz.ars.ars.mgmt.tasks;

/**
 * Interface für Tasks, die angehalten werden, wenn das Archivsystem überlastet ist.
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
public interface SuspendableTask {
	//Dieses Interface exitsiert nur, damit das Testen der FileSystemBackup, KeydoxBackup und DVDBackup
	//auch ohne "echten" Task durchgeführt werden kann.

	/**
	 * Hält den Task an, falls sich das Archivsystem in einem kritischen Zustand befindet. Wird das Archivsystem beendet, wird der Task fortgesetzt, so dass er
	 * seine Aufgabe noch vollständig erfüllen kann. {@link #isTerminated} liefert anschließend <code>true</code> zurück.
	 */
	public void suspendTaskIfNecessary();

	/**
	 * Zeigt an, ob der Task beendet werden soll.
	 *
	 * @return <code>true</code> falls der Task beendet werden soll.
	 */
	public boolean shouldTerminate();
}
