/*
 *
 * Copyright 2010 by Kappich Systemberatung Aachen
 * 
 * This file is part of de.bsvrz.ars.ars.
 * 
 * de.bsvrz.ars.ars is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * de.bsvrz.ars.ars is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.ars.ars.  If not, see <http://www.gnu.org/licenses/>.

 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436 
 * mail: <info@kappich.de>
 */

package de.bsvrz.ars.ars.persistence;

import java.io.File;

/**
 * Hilfsklasse, die einen einfachen, lesenden Zugriff auf ContainerDateien über die {@link de.bsvrz.ars.ars.persistence.ContainerFile}-Klasse bietet. Dies wird
 * von {@link de.bsvrz.ars.ars.repair.ContainerRescue} benötigt, um Container einzulesen und die Indexdateien zu reparieren, ohne einen {@link
 * de.bsvrz.ars.ars.persistence.PersistenceManager} zu starten.
 *
 * @author Kappich Systemberatung
 * @version $Revision$
 */
public class ContainerFileReader implements AutoCloseable{

	private ContainerFile _containerFile;

	/**
	 * Erzeigt einen ContainerFileReader
	 *
	 * @param file Zu lesende Containerdatei
	 *
	 * @throws PersistenceException Persistenzfehler
	 */
	public ContainerFileReader(File file) throws PersistenceException {
		_containerFile = new ContainerFile();
		_containerFile.accessContainerReadOnly(file);
		_containerFile.readContainerHeader();
	}

	public long readHeaderAsLong(KeyValParam header) throws PersistenceException {
		return _containerFile.getContHdrParamAsLong(header);
	}

	public String readHeaderAsString(KeyValParam header) throws PersistenceException {
		return _containerFile.getContHdrParamAsString(header);
	}

	public boolean readHeaderAsBool(KeyValParam header) throws PersistenceException {
		return _containerFile.getContHdrParamAsBool(header);
	}

	public int readHeaderAsInt(KeyValParam header) throws PersistenceException {
		return _containerFile.getContHdrParamAsInt(header);
	}

	public ContainerDataIterator getDataIterator() throws PersistenceException {
		return _containerFile.iterGetDataIterator(true);
	}

	public long getContainerId() {
		return _containerFile.getContainerId();
	}

	public void close() throws PersistenceException {
		try {
			_containerFile.leaveContainer();
		}
		finally {
			_containerFile = null;
		}
	}
}
