/*
 *
 * Copyright 2017 by Kappich Systemberatung Aachen
 * 
 * This file is part of de.bsvrz.ars.ars.
 * 
 * de.bsvrz.ars.ars is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * de.bsvrz.ars.ars is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.ars.ars.  If not, see <http://www.gnu.org/licenses/>.

 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436 
 * mail: <info@kappich.de>
 */

package de.bsvrz.ars.ars.persistence;

import de.bsvrz.ars.ars.persistence.iter.DataIterator;

import java.util.NoSuchElementException;

/**
 * TBD Dokumentation
 *
 * @author Kappich Systemberatung
 */
public class DataIteratorAdapter implements DataIterator {

	private boolean _finished = false;
	private ContainerDataIterator _archiveData;
	private byte[] _data;
	private long _containerIndex;
	private long _containerID;

	public DataIteratorAdapter(final ContainerDataIterator archiveData, final long containerIndex, final long containerID) throws PersistenceException {
		_archiveData = archiveData;
		_containerIndex = containerIndex;
		_containerID = containerID;
		_finished = !_archiveData.readNextDataHdr();
	}

	@Override
	public void peek(final ContainerDataResult result) throws PersistenceException {
		if(_finished) {
			throw new NoSuchElementException();
		}
		if(_data == null && result.getInflater() != null){
			_data = _archiveData.getRawData(result.getInflater());
		}
		result.setArchiveTime(_archiveData.getArcTime());
		result.setCompressed(_archiveData.isCompressed());
		result.setData(_data);
		result.setDataIndex(_archiveData.getDataIndex());
		result.setDataKind(_archiveData.getArchiveDataKind());
		result.setDataSize(_archiveData.getDataSize());
		result.setDataTime(_archiveData.getDataTime());
		result.setDataUncSize(_archiveData.getDataUncSize());
		result.setNodata(_archiveData.isNoData());
		result.setNoRights(_archiveData.isNoRights());
		result.setNoSource(_archiveData.isNoSource());
		result.setPotDataGap(_archiveData.isPotDataGap());
		result.setStillCompressed(_archiveData.isStillCompressed());
		result.setUseExtraBuffer(_archiveData.mustUseExtraBuffer());
		result.setContainerID(_containerID);
	}

	@Override
	public long peekDataIndex() {
		if(_finished) {
			throw new NoSuchElementException();
		}
		return _archiveData.getDataIndex();
	}

	@Override
	public long peekDataTime() {
		if(_finished) {
			throw new NoSuchElementException();
		}
		return _archiveData.getDataTime();
	}

	@Override
	public long peekArchiveTime() {
		if(_finished) {
			throw new NoSuchElementException();
		}
		return _archiveData.getArcTime();
	}

	@Override
	public void remove() throws PersistenceException {
		if(_finished) {
			throw new NoSuchElementException();
		}
		if(_data == null) {
			_archiveData.skipData();
		}
		else {
			_data = null;
		}
		_finished = !_archiveData.readNextDataHdr();
	}

	@Override
	public boolean isEmpty() {
		return _finished;
	}

	@Override
	public void close() throws PersistenceException {
		_archiveData.close();
		_data = null;
	}

	@Override
	public long getCurContFileIdx() {
		return _containerIndex;
	}
}
